@@ -18,29 +18,31 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
-#include "torkconfig.h"
-#include "update.h"
-#include "crypto.h"
-#include "torclient.h"
+ 
+#include <tqvaluevector.h>
+#include <tqpushbutton.h>
+#include <tqpixmap.h>
+#include <tqtimer.h>
 
 #include <tdeapplication.h>
-#include <ntqpushbutton.h>
-#include <ntqpixmap.h>
-#include <ntqtimer.h>
-#include <stdlib.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
 #include <kprocio.h>
 #include <kdebug.h>
-#include <stdlib.h>
 #include <dcopref.h>
 #include <tdeconfig.h>
 #include <tdemessagebox.h>
 #include <tdelocale.h>
 #include <krun.h>
-#include <ntqvaluevector.h>
+
+#include <stdlib.h>
 
 #include "functions.h"
+#include "torkconfig.h"
+#include "update.h"
+#include "crypto.h"
+#include "torclient.h"
+
 
 TorClient* client;
 KProcIO *whichproc;
@@ -293,9 +295,9 @@ FirstRunWizard::accept()
     paths = ":/usr/local/sbin:/usr/sbin:/sbin:/usr/local/bin:/usr/bin:/bin";
     paths.replace("::",":");
 
-    torknetstat = getFullLocation(paths,"torknetstat");;
+    torknetstat = getFullLocation(paths.local8Bit(), "torknetstat");
 
-    if (torknetstat)
+    if (!torknetstat.isEmpty())
         TorkConfig::setNetstatLocation("torknetstat");
     else
         TorkConfig::setNetstatLocation("netstat");
@@ -330,12 +332,12 @@ FirstRunWizard::accept()
     TorkConfig::setOriginalHttpProxy(OriginalHttpProxy);
     TorkConfig::setOriginalHttpsProxy(OriginalHttpsProxy);
     TorkConfig::setOriginalProxyType(OriginalProxyType);
-    TorkConfig::setOriginalCookies(OriginalCookies);
-    TorkConfig::setOriginalUseCache(OriginalUseCache);
-    TorkConfig::setOriginalSendUserAgent(OriginalSendUserAgent);
-    TorkConfig::setOriginalEnableJavascript(OriginalEnableJavascript);
-    TorkConfig::setOriginalEnableJava(OriginalEnableJava);
-    TorkConfig::setOriginalEnablePlugins(OriginalEnablePlugins);
+    TorkConfig::setOriginalCookies(OriginalCookies == "true");
+    TorkConfig::setOriginalUseCache(OriginalUseCache == "true");
+    TorkConfig::setOriginalSendUserAgent(OriginalSendUserAgent == "true");
+    TorkConfig::setOriginalEnableJavascript(OriginalEnableJavascript == "true");
+    TorkConfig::setOriginalEnableJava(OriginalEnableJava == "true");
+    TorkConfig::setOriginalEnablePlugins(OriginalEnablePlugins == "true");
 
     //Anon Proxy Settings
 
