@@ -1312,7 +1312,7 @@ void torkView::activeServersUpdated( const TQStringList &servers)
 	{
 		if ((*it).isEmpty())
 			continue;
-        if ( (tm = serverList->findItem((*it),1)) > 0){
+        if ( (tm = serverList->findItem((*it),1)) != NULL){
             tm->setPixmap(0,TQPixmap(SmallIcon("tork_green")));
         }else{
             tm = new TQListViewItem(serverList, (*it));
